@@ -13,9 +13,7 @@ from Products.CMFCore.utils import getToolByName
 from DateTime import DateTime
 
 class list_view(BrowserView):
-    """
-        Browser view class, lists classifieds and categories within the Classifieds
-    """
+    """BrowserView class, lists classifieds and categories within the Classifieds"""
     def quotestring(self, string):
         """Adds a quote to the given string"""
         return '"%s"' % string
@@ -43,6 +41,8 @@ class list_view(BrowserView):
         sort_order = ""
         searchstring = ""
         sort_on = "sortable_title"
+        
+        
 
         if self.request.form.get('sort_order'):
             sort_order = self.request.form.get('sort_order')
@@ -62,12 +62,12 @@ class list_view(BrowserView):
                 tmpresults = searchstring
 
             if tmpresults != '*':
-                query = {'portal_type' : ["Classified"], "SearchableText" : tmpresults, 'sort_on' : sort_on, "sort_order" : sort_order };
+                query = {'portal_type' : ["Classified"], "SearchableText" : tmpresults, 'sort_on' : sort_on, "sort_order" : sort_order}
                 query['path'] = {'query':'/'.join(self.context.getPhysicalPath())}
                 results = CatalogSearch(self.context, query)()
 
                 if len(results) > 0:
-                    return results;
+                    return results
         return False
 
     def getNumberOfClassifieds(self, item):
