@@ -7,14 +7,13 @@ from zope.interface import implements
 import interfaces
 from Products.CMFPlone import utils
 from Acquisition import aq_inner,aq_parent
-# from DateTime import DateTime
-from AccessControl import getSecurityManager;
+from AccessControl import getSecurityManager
 from Products.CMFCore.utils import getToolByName
-
-
 from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin
 from collective.classifieds.config import *
 
+
+
 schema = Schema((
 
     TextField(
@@ -51,6 +50,26 @@ schema = Schema((
                    'listing' :  (16, 16),
                   },
     ),
+    ImageField(
+        name='additionalimage',
+        widget=ImageField._properties['widget'](
+            label="Additional image",
+            description="Additional image of the classified",
+            label_msgid="classifieds_classified_additionalimage",
+            description_msgid="classifieds_classified_additionalimage_description",
+            i18n_domain='classifieds',
+        ),
+        storage=AttributeStorage(),
+        max_size=(768,768),
+        sizes= {'large'   : (768, 768),
+                   'preview' : (400, 400),
+                   'mini'    : (200, 200),
+                   'thumb'   : (128, 128),
+                   'tile'    :  (64, 64),
+                   'icon'    :  (32, 32),
+                   'listing' :  (16, 16),
+                  },
+    ),
     FloatField(
         name='price',
         widget=DecimalWidget(
@@ -64,6 +83,7 @@ schema = Schema((
         required=False,
         searchable=True,
     ),
+    
 ),
 )
 
@@ -95,16 +115,16 @@ class Classified(BaseContent, BrowserDefaultMixin):
         """checks if the classified has a image"""
         if self.getImage():
             return True
-
         return False
 
     def getImageTile(self, **kwargs):
-        """Get image tile url, for use in templates"""
+        """Get image tile url, relative to plone site."""
         if self.hasImage():
-            imgtileurl = '/'  + self.getImage().absolute_url(1) + '_tile'
-
+            imgtileurl = self.getImage().absolute_url(1) + '_tile'
+            portal_url = getToolByName(self, 'portal_url').getPortalObject().absolute_url(1)
+            imgtileurl = imgtileurl.replace(portal_url, '')
             return imgtileurl
-        return ''
+        return ''    
 
     def getClassifiedsCategory(self):
         """Get classifieds category"""
@@ -122,7 +142,6 @@ class Classified(BaseContent, BrowserDefaultMixin):
                 return True
         return False
 
-
     def delete(self):
         """Delete this object"""
         parent = self.aq_inner.aq_parent
