@@ -10,6 +10,8 @@ from config import product_globals
 from Globals import package_home
 from Products.CMFCore.utils import getToolByName
 import transaction
+from Products.CMFPlone.utils import log
+from OFS.CopySupport import CopyContainer
 
 def isNotClassifiedsProfile(context):
     return context.readDataFile("Classifieds_marker.txt") is None
